@@ -2,8 +2,8 @@ __author__ = ", ".join(["Shyue Ping Ong", "Anubhav Jain", "Geoffroy Hautier",
                         "William Davidson Richard", "Stephen Dacek",
                         "Michael Kocher", "Dan Gunter", "Shreyas Cholia",
                         "Vincent L Chevrier", "Rickard Armiento"])
-__date__ = "Apr 19 2013"
-__version__ = "2.7.0"
+__date__ = "May 12 2013"
+__version__ = "2.7.1"
 
 #Useful aliases for commonly used objects and modules.
 
@@ -11,5 +11,5 @@ from .core import *
 from .serializers.json_coders import PMGJSONEncoder, PMGJSONDecoder
 from .electronic_structure.core import Spin, Orbital
 from .util.io_utils import zopen
-from .io.smartio import read_structure, write_structure
+from .io.smartio import read_structure, write_structure, read_mol, write_mol
 from .matproj.rest import MPRester
