@@ -280,14 +280,13 @@ class TransformedStructure(MSONable):
         """
         return self._structures[-1]
 
-    @staticmethod
-    def from_dict(d):
+    @classmethod
+    def from_dict(cls, d):
         """
         Creates a TransformedStructure from a dict.
         """
         s = Structure.from_dict(d)
-        return TransformedStructure(s, [], d["history"],
-                                    d.get("other_parameters", None))
+        return cls(s, [], d["history"], d.get("other_parameters", None))
 
     @property
     def history(self):
@@ -370,7 +369,7 @@ class TransformedStructure(MSONable):
                              "strings with proper VASP5 element symbols.")
         raw_string = re.sub("'", "\"", poscar_string)
         s = p.structure
-        source_info = {"source": "uploaded POSCAR",
+        source_info = {"source": "POSCAR",
                        "datetime": str(datetime.datetime.now()),
                        "original_file": raw_string}
         return TransformedStructure(s, transformations, [source_info])
