@@ -46,7 +46,6 @@ from pymatgen.io.vaspio.vasp_input import Poscar
 from pymatgen.core.sites import PeriodicSite
 from pymatgen.core.structure import Structure
 from pymatgen.symmetry.finder import SymmetryFinder
-from pymatgen.core.structure_modifier import SupercellMaker
 from pymatgen.core.periodic_table import DummySpecie
 from pymatgen.util.io_utils import which
 from pymatgen.util.decorators import requires
@@ -311,9 +310,9 @@ class EnumlibAdaptor(object):
                     transformation = [[int(round(cell)) for cell in row]
                                       for row in transformation]
                     logger.debug("Supercell matrix: {}".format(transformation))
-                    maker = SupercellMaker(ordered_structure, transformation)
-                    sites.extend([site.to_unit_cell
-                                  for site in maker.modified_structure])
+                    s = Structure.from_sites(ordered_structure)
+                    s.make_supercell(transformation)
+                    sites.extend([site.to_unit_cell for site in s])
                     super_latt = sites[-1].lattice
                 else:
                     super_latt = new_latt
