@@ -17,7 +17,7 @@ __date__ = "Nov 10, 2012"
 import re
 import collections
 from fractions import gcd
-
+from itertools import chain
 from pymatgen.core.periodic_table import smart_element_or_specie, Element
 from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
@@ -113,11 +113,8 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
         return self._elmap.get(smart_element_or_specie(el), 0)
 
     def __eq__(self, other):
-        for el in self.elements:
-            if self[el] != other[el]:
-                return False
-        for el in other.elements:
-            if self[el] != other[el]:
+        for el in chain(self.elements, other.elements):
+            if abs(self[el] - other[el]) > Composition.amount_tolerance:
                 return False
         return True
 
@@ -459,8 +456,8 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
     def __repr__(self):
         return "Comp: " + self.formula
 
-    @staticmethod
-    def from_dict(d):
+    @classmethod
+    def from_dict(cls, d):
         """
         Creates a composition from a dict generated by to_dict. Strictly not
         necessary given that the standard constructor already takes in such an
@@ -472,7 +469,7 @@ class Composition(collections.Mapping, collections.Hashable, MSONable):
             d:
                 {symbol: amount} dict.
         """
-        return Composition(d)
+        return cls(d)
 
     def get_el_amt_dict(self):
         """
