@@ -24,9 +24,11 @@ class Enum(set):
             return name
         raise AttributeError
 
+
 class AttrDict(dict):
     """
-    Allows to access dict keys as obj.foo in addition to the traditional way obj['foo']"
+    Allows to access dict keys as obj.foo in addition to the traditional way
+    obj['foo']"
     """
     def __init__(self, *args, **kwargs):
         super(AttrDict, self).__init__(*args, **kwargs)
