@@ -765,7 +765,7 @@ class Specie(MSONable):
         m = re.search("([A-Z][a-z]*)([0-9\.]*)([\+\-])", species_string)
         if m:
             num = 1 if m.group(2) == "" else float(m.group(2))
-            return Specie(m.group(1), num if m.group(3) == "+" else -num)
+            return Specie(m.group(1), -num if m.group(3) == "-" else num)
         else:
             raise ValueError("Invalid Species String")
 
@@ -845,10 +845,10 @@ class Specie(MSONable):
                 "oxidation_state": self._oxi_state,
                 "properties": self._properties}
 
-    @staticmethod
-    def from_dict(d):
-        return Specie(d["element"], d["oxidation_state"],
-                      d.get("properties", None))
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["element"], d["oxidation_state"],
+                   d.get("properties", None))
 
 
 @cached_class
@@ -985,7 +985,7 @@ class DummySpecie(MSONable):
                 return DummySpecie(m.group(1))
             else:
                 num = 1 if m.group(2) == "" else float(m.group(2))
-                oxi = num if m.group(3) == "+" else -num
+                oxi = -num if m.group(3) == "-" else num
                 return DummySpecie(m.group(1), oxidation_state=oxi)
         raise ValueError("Invalid Species String")
 
@@ -997,10 +997,21 @@ class DummySpecie(MSONable):
                 "oxidation_state": self._oxi_state,
                 "properties": self._properties}
 
-    @staticmethod
-    def from_dict(d):
-        return DummySpecie(d["element"], d["oxidation_state"],
-                           d.get("properties", None))
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["element"], d["oxidation_state"],
+                   d.get("properties", None))
+
+    def __repr__(self):
+        return "DummySpecie " + self.__str__()
+
+    def __str__(self):
+        output = self.symbol
+        if self._oxi_state >= 0:
+            output += formula_double_format(self._oxi_state) + "+"
+        else:
+            output += formula_double_format(-self._oxi_state) + "-"
+        return output
 
 
 @singleton
@@ -1071,7 +1082,8 @@ def smart_element_or_specie(obj):
     """
     Utility method to get an Element or Specie from an input obj.
     If obj is in itself an element or a specie, it is returned automatically.
-    If obj is an int, the Element with the atomic number obj is returned.
+    If obj is an int or a string representing an integer, the Element
+    with the atomic number obj is returned.
     If obj is a string, Specie parsing will be attempted (e.g., Mn2+), failing
     which Element parsing will be attempted (e.g., Mn), failing which
     DummyElement parsing will be attempted.
@@ -1089,21 +1101,28 @@ def smart_element_or_specie(obj):
     Raises:
         ValueError if obj cannot be converted into an Element or Specie.
     """
-    t = type(obj)
-    if t in (Element, Specie, DummySpecie):
+    if isinstance(obj, (Element, Specie, DummySpecie)):
         return obj
-    elif t == int:
-        return Element.from_Z(obj)
-    else:
-        obj = str(obj)
+
+    def string_is_int(s):
+        """True is string s represents an integer (with sign)"""
+        if s[0] in ('-', '+'):
+            return s[1:].isdigit()
+        return s.isdigit()
+
+    obj = str(obj)
+
+    if string_is_int(obj):
+        return Element.from_Z(int(obj))
+
+    try:
+        return Specie.from_string(obj)
+    except (ValueError, KeyError):
         try:
-            return Specie.from_string(obj)
+            return Element(obj)
         except (ValueError, KeyError):
             try:
-                return Element(obj)
-            except (ValueError, KeyError):
-                try:
-                    return DummySpecie.from_string(obj)
-                except:
-                    raise ValueError("Can't parse Element or String from " +
-                                     str(obj))
+                return DummySpecie.from_string(obj)
+            except:
+                raise ValueError("Can't parse Element or String from " +
+                                 str(obj))
