@@ -35,8 +35,10 @@ from pymatgen.apps.borg.hive import VaspToComputedEntryDrone
 from pymatgen.apps.borg.queen import BorgQueen
 from pymatgen.matproj.snl import StructureNL
 from pymatgen.serializers.json_coders import PMGJSONEncoder
+from pymatgen.util.decorators import cached_class
 
 
+@cached_class
 class MPRester(object):
     """
     A class to conveniently interface with the Materials Project REST
@@ -52,11 +54,12 @@ class MPRester(object):
 
     supported_properties = ("energy", "energy_per_atom", "volume",
                             "formation_energy_per_atom", "nsites",
-                            "unit_cell_formula", "pretty_formula", "is_hubbard",
-                            "elements", "nelements", "e_above_hull", "hubbards",
-                            "is_compatible", "spacegroup", "task_ids",
-                            "band_gap", "density", "icsd_id", "cif",
-                            "total_magnetization", "material_id")
+                            "unit_cell_formula", "pretty_formula",
+                            "is_hubbard", "elements", "nelements",
+                            "e_above_hull", "hubbards", "is_compatible",
+                            "spacegroup", "task_ids", "band_gap", "density",
+                            "icsd_id", "cif", "total_magnetization",
+                            "material_id")
 
     def __init__(self, api_key=None, host="www.materialsproject.org"):
         """
@@ -341,8 +344,7 @@ class MPRester(object):
                 if data["valid_response"]:
                     if data.get("warning"):
                         warnings.warn(data["warning"])
-                    return DictVaspInputSet("MaterialsProjectVaspInputSet",
-                                            data["response"])
+                    return DictVaspInputSet("MPVaspInputSet", data["response"])
                 else:
                     raise MPRestError(data["error"])
 
@@ -645,9 +647,4 @@ class MPRestError(Exception):
     Exception class for MPRestAdaptor.
     Raised when the query has problems, e.g., bad query format.
     """
-
-    def __init__(self, msg):
-        self.msg = msg
-
-    def __str__(self):
-        return "Materials Project REST Error : " + self.msg
+    pass
