@@ -323,7 +323,7 @@ class FileLock(object):
                 self.fd = os.open(self.lockfile,
                                   os.O_CREAT | os.O_EXCL | os.O_RDWR)
                 break
-            except (OSError,), e:
+            except (OSError,) as e:
                 if e.errno != errno.EEXIST:
                     raise
                 if (time.time() - start_time) >= self.timeout:
